@@ -2,7 +2,7 @@ GQuark  bd_mpath_error_quark (void) {
         return g_quark_from_static_string ("g-bd-mpath-error-quark");
 }
 
-static const gchar const * const mpath_functions[] = {
+static const gchar* const mpath_functions[] = {
     "bd_mpath_is_tech_avail",
     "bd_mpath_flush_mpaths",
     "bd_mpath_is_mpath_member",
@@ -10,7 +10,7 @@ static const gchar const * const mpath_functions[] = {
     "bd_mpath_set_friendly_names",
     NULL};
 
-gchar const * const * get_mpath_functions (void) {
+const gchar* const* get_mpath_functions (void) {
     return mpath_functions;
 }
 
@@ -20,14 +20,14 @@ guint8 get_mpath_num_functions (void) {
     return mpath_num_functions;
 }
 
-gboolean  bd_mpath_is_tech_avail_stub (BDMpathTech tech, guint64 mode, GError **error) {
+static gboolean  bd_mpath_is_tech_avail_stub (BDMpathTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_mpath_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_mpath_is_tech_avail) (BDMpathTech tech, guint64 mode, GError **error) = bd_mpath_is_tech_avail_stub;
+static gboolean  (*_bd_mpath_is_tech_avail) (BDMpathTech tech, guint64 mode, GError **error) = bd_mpath_is_tech_avail_stub;
 
 /**
  * bd_mpath_is_tech_avail:
@@ -43,14 +43,14 @@ gboolean  bd_mpath_is_tech_avail (BDMpathTech tech, guint64 mode, GError **error
 }
 
 
-gboolean  bd_mpath_flush_mpaths_stub (GError **error) {
+static gboolean  bd_mpath_flush_mpaths_stub (GError **error) {
     g_critical ("The function 'bd_mpath_flush_mpaths' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_flush_mpaths' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_mpath_flush_mpaths) (GError **error) = bd_mpath_flush_mpaths_stub;
+static gboolean  (*_bd_mpath_flush_mpaths) (GError **error) = bd_mpath_flush_mpaths_stub;
 
 /**
  * bd_mpath_flush_mpaths:
@@ -67,14 +67,14 @@ gboolean  bd_mpath_flush_mpaths (GError **error) {
 }
 
 
-gboolean  bd_mpath_is_mpath_member_stub (const gchar *device, GError **error) {
+static gboolean  bd_mpath_is_mpath_member_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_mpath_is_mpath_member' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_is_mpath_member' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_mpath_is_mpath_member) (const gchar *device, GError **error) = bd_mpath_is_mpath_member_stub;
+static gboolean  (*_bd_mpath_is_mpath_member) (const gchar *device, GError **error) = bd_mpath_is_mpath_member_stub;
 
 /**
  * bd_mpath_is_mpath_member:
@@ -91,14 +91,14 @@ gboolean  bd_mpath_is_mpath_member (const gchar *device, GError **error) {
 }
 
 
-gchar** bd_mpath_get_mpath_members_stub (GError **error) {
+static gchar** bd_mpath_get_mpath_members_stub (GError **error) {
     g_critical ("The function 'bd_mpath_get_mpath_members' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_get_mpath_members' called, but not implemented!");
     return NULL;
 }
 
-gchar** (*_bd_mpath_get_mpath_members) (GError **error) = bd_mpath_get_mpath_members_stub;
+static gchar** (*_bd_mpath_get_mpath_members) (GError **error) = bd_mpath_get_mpath_members_stub;
 
 /**
  * bd_mpath_get_mpath_members:
@@ -115,14 +115,14 @@ gchar** bd_mpath_get_mpath_members (GError **error) {
 }
 
 
-gboolean  bd_mpath_set_friendly_names_stub (gboolean enabled, GError **error) {
+static gboolean  bd_mpath_set_friendly_names_stub (gboolean enabled, GError **error) {
     g_critical ("The function 'bd_mpath_set_friendly_names' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_mpath_set_friendly_names' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_mpath_set_friendly_names) (gboolean enabled, GError **error) = bd_mpath_set_friendly_names_stub;
+static gboolean  (*_bd_mpath_set_friendly_names) (gboolean enabled, GError **error) = bd_mpath_set_friendly_names_stub;
 
 /**
  * bd_mpath_set_friendly_names:
