@@ -71,13 +71,14 @@ static const gchar* const nvdimm_functions[] = {
     "bd_nvdimm_namespace_info",
     "bd_nvdimm_list_namespaces",
     "bd_nvdimm_namespace_reconfigure",
+    "bd_nvdimm_namepace_get_supported_sector_sizes",
     NULL};
 
 const gchar* const* get_nvdimm_functions (void) {
     return nvdimm_functions;
 }
 
-static const guint8 nvdimm_num_functions = 9;
+static const guint8 nvdimm_num_functions = 10;
 
 guint8 get_nvdimm_num_functions (void) {
     return nvdimm_num_functions;
@@ -304,6 +305,29 @@ gboolean  bd_nvdimm_namespace_reconfigure (const gchar* namespace, BDNVDIMMNames
 }
 
 
+static const guint64 * bd_nvdimm_namepace_get_supported_sector_sizes_stub (BDNVDIMMNamespaceMode mode, GError **error) {
+    g_critical ("The function 'bd_nvdimm_namepace_get_supported_sector_sizes' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_nvdimm_namepace_get_supported_sector_sizes' called, but not implemented!");
+    return 0;
+}
+
+static const guint64 * (*_bd_nvdimm_namepace_get_supported_sector_sizes) (BDNVDIMMNamespaceMode mode, GError **error) = bd_nvdimm_namepace_get_supported_sector_sizes_stub;
+
+/**
+ * bd_nvdimm_namepace_get_supported_sector_sizes:
+ * @mode: namespace mode
+ * @error: (out): place to store error if any
+ *
+ * Returns: (transfer none) (array zero-terminated=1): list of supported sector sizes for @mode
+ *
+ * Tech category: %BD_NVDIMM_TECH_NAMESPACE-%BD_NVDIMM_TECH_MODE_QUERY
+ */
+const guint64 * bd_nvdimm_namepace_get_supported_sector_sizes (BDNVDIMMNamespaceMode mode, GError **error) {
+    return _bd_nvdimm_namepace_get_supported_sector_sizes (mode, error);
+}
+
+
 gpointer load_nvdimm_from_plugin(const gchar *so_name) {
     void *handle = NULL;
     char *error = NULL;
@@ -379,6 +403,11 @@ gpointer load_nvdimm_from_plugin(const gchar *so_name) {
     if ((error = dlerror()) != NULL)
         g_warning("failed to load bd_nvdimm_namespace_reconfigure: %s", error);
 
+    dlerror();
+    * (void**) (&_bd_nvdimm_namepace_get_supported_sector_sizes) = dlsym(handle, "bd_nvdimm_namepace_get_supported_sector_sizes");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_nvdimm_namepace_get_supported_sector_sizes: %s", error);
+
     return handle;
 }
 
@@ -395,6 +424,7 @@ gboolean unload_nvdimm (gpointer handle) {
     _bd_nvdimm_namespace_info = bd_nvdimm_namespace_info_stub;
     _bd_nvdimm_list_namespaces = bd_nvdimm_list_namespaces_stub;
     _bd_nvdimm_namespace_reconfigure = bd_nvdimm_namespace_reconfigure_stub;
+    _bd_nvdimm_namepace_get_supported_sector_sizes = bd_nvdimm_namepace_get_supported_sector_sizes_stub;
 
     dlerror();
     * (void**) (&close_fn) = dlsym(handle, "bd_nvdimm_close");
