@@ -13,7 +13,10 @@ GQuark  bd_part_error_quark (void) {
  * @flags: bit combination of partition's flags (#BDPartFlag)
  */
 BDPartSpec* bd_part_spec_copy (BDPartSpec *data) {
-        BDPartSpec *ret = g_new0 (BDPartSpec, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDPartSpec *ret = g_new0 (BDPartSpec, 1);
 
     ret->path = g_strdup (data->path);
     ret->name = g_strdup (data->name);
@@ -26,7 +29,10 @@ BDPartSpec* bd_part_spec_copy (BDPartSpec *data) {
 }
 
 void  bd_part_spec_free (BDPartSpec *data) {
-        g_free (data->path);
+        if (data == NULL)
+        return;
+
+    g_free (data->path);
     g_free (data->name);
     g_free (data->type_guid);
     g_free (data);
@@ -53,7 +59,10 @@ GType  bd_part_spec_get_type () {
  * @flags: bit combination of the disk's flags (#BDPartDiskFlag)
  */
 BDPartDiskSpec* bd_part_disk_spec_copy (BDPartDiskSpec *data) {
-        BDPartDiskSpec *ret = g_new0 (BDPartDiskSpec, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDPartDiskSpec *ret = g_new0 (BDPartDiskSpec, 1);
 
     ret->path = g_strdup (data->path);
     ret->table_type = data->table_type;
@@ -65,7 +74,10 @@ BDPartDiskSpec* bd_part_disk_spec_copy (BDPartDiskSpec *data) {
 }
 
 void  bd_part_disk_spec_free (BDPartDiskSpec *data) {
-        g_free (data->path);
+        if (data == NULL)
+        return;
+
+    g_free (data->path);
     g_free (data);
 }
 
@@ -115,14 +127,14 @@ guint8 get_part_num_functions (void) {
     return part_num_functions;
 }
 
-gboolean  bd_part_is_tech_avail_stub (BDPartTech tech, guint64 mode, GError **error) {
+static gboolean  bd_part_is_tech_avail_stub (BDPartTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_part_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_is_tech_avail) (BDPartTech tech, guint64 mode, GError **error) = bd_part_is_tech_avail_stub;
+static gboolean  (*_bd_part_is_tech_avail) (BDPartTech tech, guint64 mode, GError **error) = bd_part_is_tech_avail_stub;
 
 /**
  * bd_part_is_tech_avail:
@@ -138,14 +150,14 @@ gboolean  bd_part_is_tech_avail (BDPartTech tech, guint64 mode, GError **error)
 }
 
 
-gboolean  bd_part_create_table_stub (const gchar *disk, BDPartTableType type, gboolean ignore_existing, GError **error) {
+static gboolean  bd_part_create_table_stub (const gchar *disk, BDPartTableType type, gboolean ignore_existing, GError **error) {
     g_critical ("The function 'bd_part_create_table' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_create_table' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_create_table) (const gchar *disk, BDPartTableType type, gboolean ignore_existing, GError **error) = bd_part_create_table_stub;
+static gboolean  (*_bd_part_create_table) (const gchar *disk, BDPartTableType type, gboolean ignore_existing, GError **error) = bd_part_create_table_stub;
 
 /**
  * bd_part_create_table:
@@ -164,14 +176,14 @@ gboolean  bd_part_create_table (const gchar *disk, BDPartTableType type, gboolea
 }
 
 
-BDPartSpec* bd_part_get_part_spec_stub (const gchar *disk, const gchar *part, GError **error) {
+static BDPartSpec* bd_part_get_part_spec_stub (const gchar *disk, const gchar *part, GError **error) {
     g_critical ("The function 'bd_part_get_part_spec' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_part_spec' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec* (*_bd_part_get_part_spec) (const gchar *disk, const gchar *part, GError **error) = bd_part_get_part_spec_stub;
+static BDPartSpec* (*_bd_part_get_part_spec) (const gchar *disk, const gchar *part, GError **error) = bd_part_get_part_spec_stub;
 
 /**
  * bd_part_get_part_spec:
@@ -188,14 +200,14 @@ BDPartSpec* bd_part_get_part_spec (const gchar *disk, const gchar *part, GError
 }
 
 
-BDPartSpec* bd_part_get_part_by_pos_stub (const gchar *disk, guint64 position, GError **error) {
+static BDPartSpec* bd_part_get_part_by_pos_stub (const gchar *disk, guint64 position, GError **error) {
     g_critical ("The function 'bd_part_get_part_by_pos' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_part_by_pos' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec* (*_bd_part_get_part_by_pos) (const gchar *disk, guint64 position, GError **error) = bd_part_get_part_by_pos_stub;
+static BDPartSpec* (*_bd_part_get_part_by_pos) (const gchar *disk, guint64 position, GError **error) = bd_part_get_part_by_pos_stub;
 
 /**
  * bd_part_get_part_by_pos:
@@ -213,14 +225,14 @@ BDPartSpec* bd_part_get_part_by_pos (const gchar *disk, guint64 position, GError
 }
 
 
-BDPartDiskSpec* bd_part_get_disk_spec_stub (const gchar *disk, GError **error) {
+static BDPartDiskSpec* bd_part_get_disk_spec_stub (const gchar *disk, GError **error) {
     g_critical ("The function 'bd_part_get_disk_spec' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_disk_spec' called, but not implemented!");
     return NULL;
 }
 
-BDPartDiskSpec* (*_bd_part_get_disk_spec) (const gchar *disk, GError **error) = bd_part_get_disk_spec_stub;
+static BDPartDiskSpec* (*_bd_part_get_disk_spec) (const gchar *disk, GError **error) = bd_part_get_disk_spec_stub;
 
 /**
  * bd_part_get_disk_spec:
@@ -236,14 +248,14 @@ BDPartDiskSpec* bd_part_get_disk_spec (const gchar *disk, GError **error) {
 }
 
 
-BDPartSpec** bd_part_get_disk_parts_stub (const gchar *disk, GError **error) {
+static BDPartSpec** bd_part_get_disk_parts_stub (const gchar *disk, GError **error) {
     g_critical ("The function 'bd_part_get_disk_parts' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_disk_parts' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec** (*_bd_part_get_disk_parts) (const gchar *disk, GError **error) = bd_part_get_disk_parts_stub;
+static BDPartSpec** (*_bd_part_get_disk_parts) (const gchar *disk, GError **error) = bd_part_get_disk_parts_stub;
 
 /**
  * bd_part_get_disk_parts:
@@ -259,14 +271,14 @@ BDPartSpec** bd_part_get_disk_parts (const gchar *disk, GError **error) {
 }
 
 
-BDPartSpec** bd_part_get_disk_free_regions_stub (const gchar *disk, GError **error) {
+static BDPartSpec** bd_part_get_disk_free_regions_stub (const gchar *disk, GError **error) {
     g_critical ("The function 'bd_part_get_disk_free_regions' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_disk_free_regions' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec** (*_bd_part_get_disk_free_regions) (const gchar *disk, GError **error) = bd_part_get_disk_free_regions_stub;
+static BDPartSpec** (*_bd_part_get_disk_free_regions) (const gchar *disk, GError **error) = bd_part_get_disk_free_regions_stub;
 
 /**
  * bd_part_get_disk_free_regions:
@@ -282,14 +294,14 @@ BDPartSpec** bd_part_get_disk_free_regions (const gchar *disk, GError **error) {
 }
 
 
-BDPartSpec* bd_part_get_best_free_region_stub (const gchar *disk, BDPartType type, guint64 size, GError **error) {
+static BDPartSpec* bd_part_get_best_free_region_stub (const gchar *disk, BDPartType type, guint64 size, GError **error) {
     g_critical ("The function 'bd_part_get_best_free_region' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_best_free_region' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec* (*_bd_part_get_best_free_region) (const gchar *disk, BDPartType type, guint64 size, GError **error) = bd_part_get_best_free_region_stub;
+static BDPartSpec* (*_bd_part_get_best_free_region) (const gchar *disk, BDPartType type, guint64 size, GError **error) = bd_part_get_best_free_region_stub;
 
 /**
  * bd_part_get_best_free_region:
@@ -314,14 +326,14 @@ BDPartSpec* bd_part_get_best_free_region (const gchar *disk, BDPartType type, gu
 }
 
 
-BDPartSpec* bd_part_create_part_stub (const gchar *disk, BDPartTypeReq type, guint64 start, guint64 size, BDPartAlign align, GError **error) {
+static BDPartSpec* bd_part_create_part_stub (const gchar *disk, BDPartTypeReq type, guint64 start, guint64 size, BDPartAlign align, GError **error) {
     g_critical ("The function 'bd_part_create_part' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_create_part' called, but not implemented!");
     return NULL;
 }
 
-BDPartSpec* (*_bd_part_create_part) (const gchar *disk, BDPartTypeReq type, guint64 start, guint64 size, BDPartAlign align, GError **error) = bd_part_create_part_stub;
+static BDPartSpec* (*_bd_part_create_part) (const gchar *disk, BDPartTypeReq type, guint64 start, guint64 size, BDPartAlign align, GError **error) = bd_part_create_part_stub;
 
 /**
  * bd_part_create_part:
@@ -346,14 +358,14 @@ BDPartSpec* bd_part_create_part (const gchar *disk, BDPartTypeReq type, guint64
 }
 
 
-gboolean  bd_part_delete_part_stub (const gchar *disk, const gchar *part, GError **error) {
+static gboolean  bd_part_delete_part_stub (const gchar *disk, const gchar *part, GError **error) {
     g_critical ("The function 'bd_part_delete_part' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_delete_part' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_delete_part) (const gchar *disk, const gchar *part, GError **error) = bd_part_delete_part_stub;
+static gboolean  (*_bd_part_delete_part) (const gchar *disk, const gchar *part, GError **error) = bd_part_delete_part_stub;
 
 /**
  * bd_part_delete_part:
@@ -370,14 +382,14 @@ gboolean  bd_part_delete_part (const gchar *disk, const gchar *part, GError **er
 }
 
 
-gboolean  bd_part_resize_part_stub (const gchar *disk, const gchar *part, guint64 size, BDPartAlign align, GError **error) {
+static gboolean  bd_part_resize_part_stub (const gchar *disk, const gchar *part, guint64 size, BDPartAlign align, GError **error) {
     g_critical ("The function 'bd_part_resize_part' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_resize_part' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_resize_part) (const gchar *disk, const gchar *part, guint64 size, BDPartAlign align, GError **error) = bd_part_resize_part_stub;
+static gboolean  (*_bd_part_resize_part) (const gchar *disk, const gchar *part, guint64 size, BDPartAlign align, GError **error) = bd_part_resize_part_stub;
 
 /**
  * bd_part_resize_part:
@@ -398,14 +410,14 @@ gboolean  bd_part_resize_part (const gchar *disk, const gchar *part, guint64 siz
 }
 
 
-gboolean  bd_part_set_part_flag_stub (const gchar *disk, const gchar *part, BDPartFlag flag, gboolean state, GError **error) {
+static gboolean  bd_part_set_part_flag_stub (const gchar *disk, const gchar *part, BDPartFlag flag, gboolean state, GError **error) {
     g_critical ("The function 'bd_part_set_part_flag' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_part_flag' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_part_flag) (const gchar *disk, const gchar *part, BDPartFlag flag, gboolean state, GError **error) = bd_part_set_part_flag_stub;
+static gboolean  (*_bd_part_set_part_flag) (const gchar *disk, const gchar *part, BDPartFlag flag, gboolean state, GError **error) = bd_part_set_part_flag_stub;
 
 /**
  * bd_part_set_part_flag:
@@ -425,14 +437,14 @@ gboolean  bd_part_set_part_flag (const gchar *disk, const gchar *part, BDPartFla
 }
 
 
-gboolean  bd_part_set_disk_flag_stub (const gchar *disk, BDPartDiskFlag flag, gboolean state, GError **error) {
+static gboolean  bd_part_set_disk_flag_stub (const gchar *disk, BDPartDiskFlag flag, gboolean state, GError **error) {
     g_critical ("The function 'bd_part_set_disk_flag' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_disk_flag' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_disk_flag) (const gchar *disk, BDPartDiskFlag flag, gboolean state, GError **error) = bd_part_set_disk_flag_stub;
+static gboolean  (*_bd_part_set_disk_flag) (const gchar *disk, BDPartDiskFlag flag, gboolean state, GError **error) = bd_part_set_disk_flag_stub;
 
 /**
  * bd_part_set_disk_flag:
@@ -450,14 +462,14 @@ gboolean  bd_part_set_disk_flag (const gchar *disk, BDPartDiskFlag flag, gboolea
 }
 
 
-gboolean  bd_part_set_part_flags_stub (const gchar *disk, const gchar *part, guint64 flags, GError **error) {
+static gboolean  bd_part_set_part_flags_stub (const gchar *disk, const gchar *part, guint64 flags, GError **error) {
     g_critical ("The function 'bd_part_set_part_flags' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_part_flags' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_part_flags) (const gchar *disk, const gchar *part, guint64 flags, GError **error) = bd_part_set_part_flags_stub;
+static gboolean  (*_bd_part_set_part_flags) (const gchar *disk, const gchar *part, guint64 flags, GError **error) = bd_part_set_part_flags_stub;
 
 /**
  * bd_part_set_part_flags:
@@ -470,6 +482,8 @@ gboolean  (*_bd_part_set_part_flags) (const gchar *disk, const gchar *part, guin
  *          not
  *
  * Note: Unsets all the other flags on the partition.
+ *       Only GPT-specific flags and the legacy boot flag are supported on GPT
+ *       partition tables.
  *
  * Tech category: %BD_PART_TECH_MODE_MODIFY_PART + the tech according to the partition table type
  */
@@ -478,14 +492,14 @@ gboolean  bd_part_set_part_flags (const gchar *disk, const gchar *part, guint64
 }
 
 
-gboolean  bd_part_set_part_name_stub (const gchar *disk, const gchar *part, const gchar *name, GError **error) {
+static gboolean  bd_part_set_part_name_stub (const gchar *disk, const gchar *part, const gchar *name, GError **error) {
     g_critical ("The function 'bd_part_set_part_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_part_name' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_part_name) (const gchar *disk, const gchar *part, const gchar *name, GError **error) = bd_part_set_part_name_stub;
+static gboolean  (*_bd_part_set_part_name) (const gchar *disk, const gchar *part, const gchar *name, GError **error) = bd_part_set_part_name_stub;
 
 /**
  * bd_part_set_part_name:
@@ -503,14 +517,14 @@ gboolean  bd_part_set_part_name (const gchar *disk, const gchar *part, const gch
 }
 
 
-gboolean  bd_part_set_part_type_stub (const gchar *disk, const gchar *part, const gchar *type_guid, GError **error) {
+static gboolean  bd_part_set_part_type_stub (const gchar *disk, const gchar *part, const gchar *type_guid, GError **error) {
     g_critical ("The function 'bd_part_set_part_type' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_part_type' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_part_type) (const gchar *disk, const gchar *part, const gchar *type_guid, GError **error) = bd_part_set_part_type_stub;
+static gboolean  (*_bd_part_set_part_type) (const gchar *disk, const gchar *part, const gchar *type_guid, GError **error) = bd_part_set_part_type_stub;
 
 /**
  * bd_part_set_part_type:
@@ -528,14 +542,14 @@ gboolean  bd_part_set_part_type (const gchar *disk, const gchar *part, const gch
 }
 
 
-gboolean  bd_part_set_part_id_stub (const gchar *disk, const gchar *part, const gchar *part_id, GError **error) {
+static gboolean  bd_part_set_part_id_stub (const gchar *disk, const gchar *part, const gchar *part_id, GError **error) {
     g_critical ("The function 'bd_part_set_part_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_set_part_id' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_part_set_part_id) (const gchar *disk, const gchar *part, const gchar *part_id, GError **error) = bd_part_set_part_id_stub;
+static gboolean  (*_bd_part_set_part_id) (const gchar *disk, const gchar *part, const gchar *part_id, GError **error) = bd_part_set_part_id_stub;
 
 /**
  * bd_part_set_part_id:
@@ -553,14 +567,14 @@ gboolean  bd_part_set_part_id (const gchar *disk, const gchar *part, const gchar
 }
 
 
-gchar* bd_part_get_part_id_stub (const gchar *disk, const gchar *part, GError **error) {
+static gchar* bd_part_get_part_id_stub (const gchar *disk, const gchar *part, GError **error) {
     g_critical ("The function 'bd_part_get_part_id' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_part_id' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_part_get_part_id) (const gchar *disk, const gchar *part, GError **error) = bd_part_get_part_id_stub;
+static gchar* (*_bd_part_get_part_id) (const gchar *disk, const gchar *part, GError **error) = bd_part_get_part_id_stub;
 
 /**
  * bd_part_get_part_id:
@@ -577,14 +591,14 @@ gchar* bd_part_get_part_id (const gchar *disk, const gchar *part, GError **error
 }
 
 
-const gchar* bd_part_get_part_table_type_str_stub (BDPartTableType type, GError **error) {
+static const gchar* bd_part_get_part_table_type_str_stub (BDPartTableType type, GError **error) {
     g_critical ("The function 'bd_part_get_part_table_type_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_part_table_type_str' called, but not implemented!");
     return NULL;
 }
 
-const gchar* (*_bd_part_get_part_table_type_str) (BDPartTableType type, GError **error) = bd_part_get_part_table_type_str_stub;
+static const gchar* (*_bd_part_get_part_table_type_str) (BDPartTableType type, GError **error) = bd_part_get_part_table_type_str_stub;
 
 /**
  * bd_part_get_part_table_type_str:
@@ -600,14 +614,14 @@ const gchar* bd_part_get_part_table_type_str (BDPartTableType type, GError **err
 }
 
 
-const gchar* bd_part_get_flag_str_stub (BDPartFlag flag, GError **error) {
+static const gchar* bd_part_get_flag_str_stub (BDPartFlag flag, GError **error) {
     g_critical ("The function 'bd_part_get_flag_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_flag_str' called, but not implemented!");
     return NULL;
 }
 
-const gchar* (*_bd_part_get_flag_str) (BDPartFlag flag, GError **error) = bd_part_get_flag_str_stub;
+static const gchar* (*_bd_part_get_flag_str) (BDPartFlag flag, GError **error) = bd_part_get_flag_str_stub;
 
 /**
  * bd_part_get_flag_str:
@@ -623,14 +637,14 @@ const gchar* bd_part_get_flag_str (BDPartFlag flag, GError **error) {
 }
 
 
-const gchar* bd_part_get_type_str_stub (BDPartType type, GError **error) {
+static const gchar* bd_part_get_type_str_stub (BDPartType type, GError **error) {
     g_critical ("The function 'bd_part_get_type_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_part_get_type_str' called, but not implemented!");
     return NULL;
 }
 
-const gchar* (*_bd_part_get_type_str) (BDPartType type, GError **error) = bd_part_get_type_str_stub;
+static const gchar* (*_bd_part_get_type_str) (BDPartType type, GError **error) = bd_part_get_type_str_stub;
 
 /**
  * bd_part_get_type_str:
