@@ -63,6 +63,7 @@ BDLVMPVdata* bd_lvm_pvdata_copy (BDLVMPVdata *data) {
     new_data->pv_size = data->pv_size;
     new_data->pe_start = data->pe_start;
     new_data->vg_name = g_strdup (data->vg_name);
+    new_data->vg_uuid = g_strdup (data->vg_uuid);
     new_data->vg_size = data->vg_size;
     new_data->vg_free = data->vg_free;
     new_data->vg_extent_size = data->vg_extent_size;
@@ -80,6 +81,7 @@ void bd_lvm_pvdata_free (BDLVMPVdata *data) {
     g_free (data->pv_name);
     g_free (data->pv_uuid);
     g_free (data->vg_name);
+    g_free (data->vg_uuid);
     g_free (data);
 }
 
@@ -371,6 +373,7 @@ static GHashTable* parse_lvm_vars (const gchar *str, guint *num_items) {
         if (g_strv_length (key_val) == 2) {
             /* we only want to process valid lines (with the '=' character) */
             g_hash_table_insert (table, key_val[0], key_val[1]);
+            g_free (key_val);
             (*num_items)++;
         } else
             /* invalid line, just free key_val */
@@ -972,6 +975,7 @@ BDLVMPVdata* bd_lvm_pvinfo (const gchar *device, GError **error) {
             if (table)
                 g_hash_table_destroy (table);
     }
+    g_strfreev (lines);
 
     /* getting here means no usable info was found */
     g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
@@ -999,24 +1003,25 @@ BDLVMPVdata** bd_lvm_pvs (GError **error) {
     gchar **lines = NULL;
     gchar **lines_p = NULL;
     guint num_items;
-    GPtrArray *pvs = g_ptr_array_new ();
+    GPtrArray *pvs;
     BDLVMPVdata *pvdata = NULL;
-    BDLVMPVdata **ret = NULL;
-    guint64 i = 0;
+
+    pvs = g_ptr_array_new ();
 
     success = call_lvm_and_capture_output (args, NULL, &output, error);
-
     if (!success) {
         if (g_error_matches (*error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_NOOUT)) {
             /* no output => no VGs, not an error */
             g_clear_error (error);
-            ret = g_new0 (BDLVMPVdata*, 1);
-            ret[0] = NULL;
-            return ret;
+            /* return an empty list */
+            g_ptr_array_add (pvs, NULL);
+            return (BDLVMPVdata **) g_ptr_array_free (pvs, FALSE);
         }
-        else
+        else {
             /* the error is already populated from the call */
+            g_ptr_array_free (pvs, TRUE);
             return NULL;
+        }
     }
 
     lines = g_strsplit (output, "\n", 0);
@@ -1039,18 +1044,13 @@ BDLVMPVdata** bd_lvm_pvs (GError **error) {
     if (pvs->len == 0) {
         g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
                      "Failed to parse information about PVs");
+        g_ptr_array_free (pvs, TRUE);
         return NULL;
     }
 
-    /* now create the return value -- NULL-terminated array of BDLVMPVdata */
-    ret = g_new0 (BDLVMPVdata*, pvs->len + 1);
-    for (i=0; i < pvs->len; i++)
-        ret[i] = (BDLVMPVdata*) g_ptr_array_index (pvs, i);
-    ret[i] = NULL;
-
-    g_ptr_array_free (pvs, FALSE);
-
-    return ret;
+    /* returning NULL-terminated array of BDLVMPVdata */
+    g_ptr_array_add (pvs, NULL);
+    return (BDLVMPVdata **) g_ptr_array_free (pvs, FALSE);
 }
 
 /**
@@ -1247,6 +1247,7 @@ BDLVMVGdata* bd_lvm_vginfo (const gchar *vg_name, GError **error) {
             if (table)
                 g_hash_table_destroy (table);
     }
+    g_strfreev (lines);
 
     /* getting here means no usable info was found */
     g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
@@ -1273,23 +1274,25 @@ BDLVMVGdata** bd_lvm_vgs (GError **error) {
     gchar **lines = NULL;
     gchar **lines_p = NULL;
     guint num_items;
-    GPtrArray *vgs = g_ptr_array_new ();
+    GPtrArray *vgs;
     BDLVMVGdata *vgdata = NULL;
-    BDLVMVGdata **ret = NULL;
-    guint64 i = 0;
+
+    vgs = g_ptr_array_new ();
 
     success = call_lvm_and_capture_output (args, NULL, &output, error);
     if (!success) {
         if (g_error_matches (*error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_NOOUT)) {
             /* no output => no VGs, not an error */
             g_clear_error (error);
-            ret = g_new0 (BDLVMVGdata*, 1);
-            ret[0] = NULL;
-            return ret;
+            /* return an empty list */
+            g_ptr_array_add (vgs, NULL);
+            return (BDLVMVGdata **) g_ptr_array_free (vgs, FALSE);
         }
-        else
+        else {
             /* the error is already populated from the call */
+            g_ptr_array_free (vgs, TRUE);
             return NULL;
+       }
     }
 
     lines = g_strsplit (output, "\n", 0);
@@ -1312,18 +1315,13 @@ BDLVMVGdata** bd_lvm_vgs (GError **error) {
     if (vgs->len == 0) {
         g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
                      "Failed to parse information about VGs");
+        g_ptr_array_free (vgs, TRUE);
         return NULL;
     }
 
-    /* now create the return value -- NULL-terminated array of BDLVMVGdata */
-    ret = g_new0 (BDLVMVGdata*, vgs->len + 1);
-    for (i=0; i < vgs->len; i++)
-        ret[i] = (BDLVMVGdata*) g_ptr_array_index (vgs, i);
-    ret[i] = NULL;
-
-    g_ptr_array_free (vgs, FALSE);
-
-    return ret;
+    /* returning NULL-terminated array of BDLVMVGdata */
+    g_ptr_array_add (vgs, NULL);
+    return (BDLVMVGdata **) g_ptr_array_free (vgs, FALSE);
 }
 
 /**
@@ -1641,6 +1639,7 @@ BDLVMLVdata* bd_lvm_lvinfo (const gchar *vg_name, const gchar *lv_name, GError *
             if (table)
                 g_hash_table_destroy (table);
     }
+    g_strfreev (lines);
 
     /* getting here means no usable info was found */
     g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
@@ -1670,27 +1669,28 @@ BDLVMLVdata** bd_lvm_lvs (const gchar *vg_name, GError **error) {
     gchar **lines = NULL;
     gchar **lines_p = NULL;
     guint num_items;
-    GPtrArray *lvs = g_ptr_array_new ();
+    GPtrArray *lvs;
     BDLVMLVdata *lvdata = NULL;
-    BDLVMLVdata **ret = NULL;
-    guint64 i = 0;
+
+    lvs = g_ptr_array_new ();
 
     if (vg_name)
         args[9] = vg_name;
 
     success = call_lvm_and_capture_output (args, NULL, &output, error);
-
     if (!success) {
         if (g_error_matches (*error, BD_UTILS_EXEC_ERROR, BD_UTILS_EXEC_ERROR_NOOUT)) {
             /* no output => no LVs, not an error */
             g_clear_error (error);
-            ret = g_new0 (BDLVMLVdata*, 1);
-            ret[0] = NULL;
-            return ret;
+            /* return an empty list */
+            g_ptr_array_add (lvs, NULL);
+            return (BDLVMLVdata **) g_ptr_array_free (lvs, FALSE);
         }
-        else
+        else {
             /* the error is already populated from the call */
+            g_ptr_array_free (lvs, TRUE);
             return NULL;
+        }
     }
 
     lines = g_strsplit (output, "\n", 0);
@@ -1713,18 +1713,13 @@ BDLVMLVdata** bd_lvm_lvs (const gchar *vg_name, GError **error) {
     if (lvs->len == 0) {
         g_set_error (error, BD_LVM_ERROR, BD_LVM_ERROR_PARSE,
                      "Failed to parse information about LVs");
+        g_ptr_array_free (lvs, TRUE);
         return NULL;
     }
 
-    /* now create the return value -- NULL-terminated array of BDLVMLVdata */
-    ret = g_new0 (BDLVMLVdata*, lvs->len + 1);
-    for (i=0; i < lvs->len; i++)
-        ret[i] = (BDLVMLVdata*) g_ptr_array_index (lvs, i);
-    ret[i] = NULL;
-
-    g_ptr_array_free (lvs, FALSE);
-
-    return ret;
+    /* returning NULL-terminated array of BDLVMLVdata */
+    g_ptr_array_add (lvs, NULL);
+    return (BDLVMLVdata **) g_ptr_array_free (lvs, FALSE);
 }
 
 /**
