@@ -1,18 +1,18 @@
 /*
  * Copyright (C) 2017  Red Hat, Inc.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
  *
- * This program is distributed in the hope that it will be useful,
+ * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  *
  * Author: Vojtech Trefny <vtrefny@redhat.com>
  */
@@ -39,7 +39,8 @@ GQuark bd_utils_module_error_quark (void)
  * @module_name: name of the kernel module to check
  * @error: (out): place to store error (if any)
  *
- * Returns: whether the @module_name was found in the system
+ * Returns: whether the @module_name was found in the system, either as a module
+ * or built-in in the kernel
  */
 gboolean bd_utils_have_kernel_module (const gchar *module_name, GError **error) {
     gint ret = 0;
@@ -48,6 +49,7 @@ gboolean bd_utils_have_kernel_module (const gchar *module_name, GError **error)
     gchar *null_config = NULL;
     const gchar *path = NULL;
     gboolean have_path = FALSE;
+    gboolean builtin = FALSE;
     locale_t c_locale = newlocale (LC_ALL_MASK, "C", (locale_t) 0);
 
     ctx = kmod_new (NULL, (const gchar * const*) &null_config);
@@ -58,7 +60,7 @@ gboolean bd_utils_have_kernel_module (const gchar *module_name, GError **error)
         return FALSE;
     }
     /* prevent libkmod from spamming our STDERR */
-    kmod_set_log_priority(ctx, LOG_CRIT);
+    kmod_set_log_priority (ctx, LOG_CRIT);
 
     ret = kmod_module_new_from_name (ctx, module_name, &mod);
     if (ret < 0) {
@@ -71,11 +73,14 @@ gboolean bd_utils_have_kernel_module (const gchar *module_name, GError **error)
 
     path = kmod_module_get_path (mod);
     have_path = (path != NULL) && (g_strcmp0 (path, "") != 0);
+    if (!have_path) {
+      builtin = kmod_module_get_initstate (mod) == KMOD_MODULE_BUILTIN;
+    }
     kmod_module_unref (mod);
     kmod_unref (ctx);
     freelocale (c_locale);
 
-    return have_path;
+    return have_path || builtin;
 }
 
 /**
@@ -101,7 +106,7 @@ gboolean bd_utils_load_kernel_module (const gchar *module_name, const gchar *opt
         return FALSE;
     }
     /* prevent libkmod from spamming our STDERR */
-    kmod_set_log_priority(ctx, LOG_CRIT);
+    kmod_set_log_priority (ctx, LOG_CRIT);
 
     ret = kmod_module_new_from_name (ctx, module_name, &mod);
     if (ret < 0) {
@@ -164,7 +169,7 @@ gboolean bd_utils_unload_kernel_module (const gchar *module_name, GError **error
         return FALSE;
     }
     /* prevent libkmod from spamming our STDERR */
-    kmod_set_log_priority(ctx, LOG_CRIT);
+    kmod_set_log_priority (ctx, LOG_CRIT);
 
     ret = kmod_module_new_from_loaded (ctx, &list);
     if (ret < 0) {
@@ -182,6 +187,7 @@ gboolean bd_utils_unload_kernel_module (const gchar *module_name, GError **error
         else
             kmod_module_unref (mod);
     }
+    kmod_module_unref_list (list);
 
     if (!found) {
         g_set_error (error, BD_UTILS_MODULE_ERROR, BD_UTILS_MODULE_ERROR_NOEXIST,
