@@ -3,10 +3,14 @@ from __future__ import division
 import unittest
 import os
 import six
+import re
 import time
 
+from distutils.version import LooseVersion
+from distutils.spawn import find_executable
+
 import overrides_hack
-from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, skip_on, mount, umount
+from utils import create_sparse_tempfile, create_lio_device, delete_lio_device, fake_utils, fake_path, mount, umount, run_command
 from gi.repository import GLib, BlockDev
 
 TEST_MNT = "/tmp/libblockdev_test_mnt"
@@ -14,13 +18,20 @@ TEST_MNT = "/tmp/libblockdev_test_mnt"
 def wipefs(device):
     os.system("wipefs -a %s > /dev/null" % device)
 
-@skip_on(("centos", "enterprise_linux"), skip_on_arch="aarch64", reason="no btrfs module on CentOS/RHEL 7 aarch64")
+
 class BtrfsTestCase(unittest.TestCase):
 
     requested_plugins = BlockDev.plugin_specs_from_names(("btrfs",))
 
     @classmethod
     def setUpClass(cls):
+
+        if not BlockDev.utils_have_kernel_module("btrfs"):
+            raise unittest.SkipTest('Btrfs kernel module not available, skipping.')
+
+        if not find_executable("btrfs"):
+            raise unittest.SkipTest("btrfs executable not foundin $PATH, skipping.")
+
         if not BlockDev.is_initialized():
             BlockDev.init(cls.requested_plugins, None)
         else:
@@ -55,6 +66,13 @@ class BtrfsTestCase(unittest.TestCase):
             pass
         os.unlink(self.dev_file2)
 
+    def _get_btrfs_version(self):
+        _ret, out, _err = run_command("btrfs --version")
+        m = re.search(r"[Bb]trfs.* v([\d\.]+)", out)
+        if not m or len(m.groups()) != 1:
+            raise RuntimeError("Failed to determine btrfs version from: %s" % out)
+        return LooseVersion(m.groups()[0])
+
 class BtrfsTestCreateQuerySimple(BtrfsTestCase):
     def test_create_and_query_volume(self):
         """Verify that btrfs volume creation and querying works"""
@@ -165,6 +183,10 @@ class BtrfsTestCreateDeleteSubvolume(BtrfsTestCase):
     def test_create_delete_subvolume(self):
         """Verify that it is possible to create/delete subvolume"""
 
+        btrfs_version = self._get_btrfs_version()
+        if btrfs_version >= LooseVersion('4.13.2'):
+            self.skipTest('subvolumes list is broken with btrfs-progs v4.13.2')
+
         succ = BlockDev.btrfs_create_volume([self.loop_dev], "myShinyBtrfs", None, None, None)
         self.assertTrue(succ)
 
@@ -467,7 +489,6 @@ class BtrfsTooSmallTestCase (BtrfsTestCase):
             pass
         os.unlink(self.dev_file2)
 
-    @skip_on("fedora", "25", reason="Min sizes for Btrfs are different on F25")
     def test_create_too_small(self):
         """Verify that an attempt to create BTRFS on a too small device fails"""
 
@@ -505,7 +526,6 @@ class BtrfsJustBigEnoughTestCase (BtrfsTestCase):
             pass
         os.unlink(self.dev_file2)
 
-    @skip_on("fedora", "25", reason="Min sizes for Btrfs are different on F25")
     def test_create_just_enough(self):
         """Verify that creating BTRFS on a just big enough devices works"""
 
