@@ -295,7 +295,7 @@ class KbdBcacheTestCase(unittest.TestCase):
             BlockDev.reinit(cls.requested_plugins, True, None)
 
     @skip_on("fedora", "29", reason="running bcache tests causes system to run out of kernel memory on rawhide")
-    @skip_on("debian", "testing", reason="running bcache tests causes system to run out of kernel memory on testing")
+    @skip_on("debian", "10", reason="running bcache tests causes system to run out of kernel memory on testing")
     def setUp(self):
         self.addCleanup(self._clean_up)
         self.dev_file = create_sparse_tempfile("lvm_test", 10 * 1024**3)
