@@ -357,7 +357,7 @@ class LvmPVVGTestCase(LvmPVonlyTestCase):
         LvmPVonlyTestCase._clean_up(self)
 
 class LvmTestVGcreateRemove(LvmPVVGTestCase):
-    @skip_on("debian", skip_on_arch="i686", reason="vgremove is broken on 32bit Debian")
+    @skip_on("debian", skip_on_version="9", skip_on_arch="i686", reason="vgremove is broken on 32bit Debian stable")
     def test_vgcreate_vgremove(self):
         """Verify that it is possible to create and destroy a VG"""
 
@@ -498,7 +498,7 @@ class LvmTestVGinfo(LvmPVVGTestCase):
         self.assertEqual(info.extent_size, 4 * 1024**2)
 
 class LvmTestVGs(LvmPVVGTestCase):
-    @skip_on("debian", skip_on_arch="i686", reason="vgremove is broken on 32bit Debian")
+    @skip_on("debian", skip_on_version="9", skip_on_arch="i686", reason="vgremove is broken on 32bit Debian stable")
     def test_vgs(self):
         """Verify that it's possible to gather info about VGs"""
 
@@ -640,7 +640,7 @@ class LvmTestLVcreateWithExtra(LvmPVVGLVTestCase):
         self.assertTrue(succ)
 
 class LvmTestLVcreateType(LvmPVVGLVTestCase):
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
+    @skip_on(("centos", "enterprise_linux"), "7")
     def test_lvcreate_type(self):
         """Verify it's possible to create LVs with various types"""
 
@@ -1098,7 +1098,7 @@ class LvmPVVGLVcachePoolTestCase(LvmPVVGLVTestCase):
 
 class LvmPVVGLVcachePoolCreateRemoveTestCase(LvmPVVGLVcachePoolTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
+    @skip_on(("centos", "enterprise_linux"), "7")
     def test_cache_pool_create_remove(self):
         """Verify that is it possible to create and remove a cache pool"""
 
@@ -1124,7 +1124,6 @@ class LvmPVVGLVcachePoolCreateRemoveTestCase(LvmPVVGLVcachePoolTestCase):
 
 class LvmTestCachePoolConvert(LvmPVVGLVcachePoolTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
     def test_cache_pool_convert(self):
         """Verify that it is possible to create a cache pool by conversion"""
 
@@ -1148,7 +1147,6 @@ class LvmTestCachePoolConvert(LvmPVVGLVcachePoolTestCase):
 
 class LvmPVVGLVcachePoolAttachDetachTestCase(LvmPVVGLVcachePoolTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
     def test_cache_pool_attach_detach(self):
         """Verify that is it possible to attach and detach a cache pool"""
 
@@ -1189,7 +1187,6 @@ class LvmPVVGLVcachePoolAttachDetachTestCase(LvmPVVGLVcachePoolTestCase):
 
 class LvmPVVGcachedLVTestCase(LvmPVVGLVTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
     def test_create_cached_lv(self):
         """Verify that it is possible to create a cached LV in a single step"""
 
@@ -1209,7 +1206,6 @@ class LvmPVVGcachedLVTestCase(LvmPVVGLVTestCase):
 
 class LvmPVVGcachedLVpoolTestCase(LvmPVVGLVTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
     def test_cache_get_pool_name(self):
         """Verify that it is possible to get the name of the cache pool"""
 
@@ -1235,7 +1231,6 @@ class LvmPVVGcachedLVpoolTestCase(LvmPVVGLVTestCase):
 
 class LvmPVVGcachedLVstatsTestCase(LvmPVVGLVTestCase):
     @unittest.skipIf("SKIP_SLOW" in os.environ, "skipping slow tests")
-    @skip_on("fedora", "27", reason="LVM is broken in many ways on rawhide")
     def test_cache_get_stats(self):
         """Verify that it is possible to get stats for a cached LV"""
 
@@ -1302,3 +1297,31 @@ class LVMUnloadTest(LVMTestCase):
         # load the plugins back
         self.assertTrue(BlockDev.reinit(self.requested_plugins, True, None))
         self.assertIn("lvm", BlockDev.get_available_plugin_names())
+
+class LVMTechTest(LVMTestCase):
+
+    def setUp(self):
+        # set init checks to false -- we want runtime checks for this
+        BlockDev.switch_init_checks(False)
+
+        # set everything back and reinit just to be sure
+        self.addCleanup(BlockDev.switch_init_checks, True)
+        self.addCleanup(BlockDev.reinit, self.requested_plugins, True, None)
+
+    def test_tech_available(self):
+        """Verify that checking lvm tool availability by technology works as expected"""
+
+        with fake_path(all_but="lvm"):
+            self.assertTrue(BlockDev.reinit(self.requested_plugins, True, None))
+
+            # no lvm tool available, should fail
+            with self.assertRaises(GLib.GError):
+                BlockDev.lvm_is_tech_avail(BlockDev.LVMTech.BASIC, BlockDev.LVMTechMode.CREATE)
+
+        # only query is support with calcs
+        with six.assertRaisesRegex(self, GLib.GError, "Only 'query' supported for thin calculations"):
+            BlockDev.lvm_is_tech_avail(BlockDev.LVMTech.THIN_CALCS, BlockDev.LVMTechMode.CREATE)
+
+        # lvm is available, should pass
+        avail = BlockDev.lvm_is_tech_avail(BlockDev.LVMTech.BASIC, BlockDev.LVMTechMode.CREATE)
+        self.assertTrue(avail)
